#!/usr/bin/python3
#-*- coding: utf-8 -*-

import sys
from pyeole.lock import acquire, release, is_locked
from eoleaaf.sambatranslator import SambaExport, erase_db as reset_db
from argparse import ArgumentParser
import traceback

from logging import getLogger

aaflog = getLogger("AAF")

def processfile(enable_transaction=False,
                erase_db=False,
                **kwargs):
    aaflog.info(20*'*')
    aaflog.info("*** Début de l'importation des comptes et des groupes")
    try:
        acquire('importad', level="system")
    except Exception as err:
        print('impossible de placer un verrou: {}'.format(err))
        sys.exit(2)
    if erase_db:
        reset_db()
    try:
        samba_import = SambaExport(aaflog,
                                   enable_transaction=enable_transaction,
                                   debug=True)
        samba_import.run()
    except Exception as err:
        traceback.print_exc()
        release('importad', level='system')
        sys.exit(3)
    aaflog.info("*** Fin de l'importation des comptes et des groupes")
    aaflog.info(20*'*')
    release('importad', level='system')
    sys.exit(0)


if __name__ == "__main__":
    parser = ArgumentParser(description="Importation des données de la base MongoDB vers l'annuaire de l'AD")
    parser.add_argument("--enable_transaction",
                        help="activer les transactions (attention ne fonctionne que pour des imports initiaux, pas les mises à jour, prévoir aussi de faire export TDB_NO_FSYNC=1 avant de lancer la commande)",
                        action="store_true")
    parser.add_argument("--erase_db",
                        help="commence par supprimer le contenu de la base de l'annuaire (a n'utiliser que si vous savez ce que vous faites !)",
                        action="store_true",
                        default=False)
    args = parser.parse_args()
    processfile(args.enable_transaction,
                args.erase_db,
                )
